(************** Content-type: application/mathematica **************
                     CreatedBy='Mathematica 4.2'

                    Mathematica-Compatible Notebook

This notebook can be used with any Mathematica-compatible
application, such as Mathematica, MathReader or Publicon. The data
for the notebook starts with the line containing stars above.

To get the notebook into a Mathematica-compatible application, do
one of the following:

* Save the data starting with the line of stars above into a file
  with a name ending in .nb, then open the file inside the
  application;

* Copy the data starting with the line of stars above to the
  clipboard, then use the Paste menu command inside the application.

Data for notebooks contains only printable 7-bit ASCII and can be
sent directly in email or through ftp in text mode.  Newlines can be
CR, LF or CRLF (Unix, Macintosh or MS-DOS style).

NOTE: If you modify the data for this notebook not in a Mathematica-
compatible application, you must delete the line below containing
the word CacheID, otherwise Mathematica-compatible applications may
try to use invalid cache data.

For more information on notebooks and Mathematica-compatible 
applications, contact Wolfram Research:
  web: http://www.wolfram.com
  email: info@wolfram.com
  phone: +1-217-398-0700 (U.S.)

Notebook reader applications are available free of charge from 
Wolfram Research.
*******************************************************************)

(*CacheID: 232*)


(*NotebookFileLineBreakTest
NotebookFileLineBreakTest*)
(*NotebookOptionsPosition[     47563,       1766]*)
(*NotebookOutlinePosition[     48271,       1790]*)
(*  CellTagsIndexPosition[     48227,       1786]*)
(*WindowFrame->Normal*)



Notebook[{
Cell["\<\
Minimal Decomposition of Hypergeometic Terms
Mitja Lu\[SHacek]trek, 2004-05-30
Based on Abramov amd Petkov\[SHacek]ek (2002), Rational Normal Forms and \
Minimal Decomposition of Hypergeometric Terms, Journal of Symbolic \
Computation 33, 521-543.\
\>", "Text"],

Cell[CellGroupData[{

Cell["Program", "Subtitle"],

Cell[CellGroupData[{

Cell["Get", "Section"],

Cell[BoxData[
    \(<< Algebra`PolynomialExtendedGCD`\)], "Input"],

Cell[CellGroupData[{

Cell[BoxData[
    \(<< "\<d:\\program files\\wolfram \
research\mathematica\\4.2\\programi\\aisb.m\>"\)], "Input"],

Cell[BoxData[
    \("N.B.: Besides GosperSum and GosperFunction, this package also contains \
FactorialSimplify (alias FS), and WZ."\)], "Print"]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{

Cell["Functions", "Section"],

Cell[BoxData[
    \(Dis[a_, \ b_, \ x_] := 
      Module[{n, \ solution, \ max}, \[IndentingNewLine]solution = 
          Solve[Resultant[a, \ b /. x \[Rule] x + n, \ x] \[Equal] 0, \ 
            n]; \[IndentingNewLine]If[
          solution \[NotEqual] {}, \[IndentingNewLine]max = 
            Max[Select[n /. solution, \ IntegerQ]]; \[IndentingNewLine]If[
            max > \(-\[Infinity]\), \[IndentingNewLine]Return[
              max]\[IndentingNewLine]]\[IndentingNewLine]]; \
\[IndentingNewLine]Return[\(-1\)]\[IndentingNewLine]]\)], "Input"],

Cell[BoxData[
    \(Pump[f_, \ g_, \ n_] := 
      Module[{ft, \ gt, \ d}, \[IndentingNewLine]ft = 
          f\ ; \[IndentingNewLine]gt = g/f; \[IndentingNewLine]d = 
          n; \[IndentingNewLine]While[
          Exponent[d, \ n] > 0, \[IndentingNewLine]d = 
            PolynomialGCD[ft, \ gt]; \[IndentingNewLine]ft = 
            ft\ *d\ ; \[IndentingNewLine]gt = 
            gt/d\[IndentingNewLine]]; \[IndentingNewLine]Return[{ft, \ 
            gt}]\[IndentingNewLine]]\)], "Input"],

Cell[BoxData[
    \(WriteAs[U2_, \ ut2_, \ qt_, \ n_] := 
      Module[{a1, \ a2, \ 
          u21}, \[IndentingNewLine]{a1, \ 
            b1} = \(PolynomialExtendedGCD[ut2, \ 
              qt]\)[\([2]\)]; \[IndentingNewLine]u21 = 
          Numerator[
            Factor[U2]]; \[IndentingNewLine]Return[{PolynomialRemainder[
              b1*u21, \ ut2, \ n], \ 
            PolynomialRemainder[a1*u21, \ qt, \ 
              n]}]\[IndentingNewLine]]\)], "Input"],

Cell[BoxData[
    \(Dcert[D_, \ U_, \ n_] := 
      Module[{U1, \ U2, \ u2, \ DF, \ d1, \ d2, \ N1, \ M, \ h, \ q, \ t, \ 
          qt, \ ut2, \ at, \ bt, \ U1a, \ v1, \ v2, \ w1, \ f1, \ w2, \ 
          f2}, \[IndentingNewLine]U1 = 0; \[IndentingNewLine]U2 = 
          U; \[IndentingNewLine]u2 = 
          Denominator[Factor[U]]; \[IndentingNewLine]DF = 
          Factor[D]; \[IndentingNewLine]d1 := 
          Numerator[DF]; \[IndentingNewLine]d2 := 
          Denominator[DF]; \[IndentingNewLine]N1 = 
          Dis[d1, \ u2, \ n]; \[IndentingNewLine]M = 
          Dis[u2, \ u2, \ n]; \[IndentingNewLine]If[
          M \[Equal] 
            0, \[IndentingNewLine]M = \(-1\)\[IndentingNewLine]]; \
\[IndentingNewLine]N1 = Max[N1, \ M]; \[IndentingNewLine]For[h = N1, \ 
          h \[GreaterEqual] 0, \ \(h--\), \[IndentingNewLine]q = 
            PolynomialGCD[u2, \ d1 /. n \[Rule] n - h]; \[IndentingNewLine]If[
            h > 0, \[IndentingNewLine]t = u2/q; \[IndentingNewLine]q = 
              q*PolynomialGCD[t, \ 
                  t /. n \[Rule] 
                      n - h]\[IndentingNewLine]]; \[IndentingNewLine]{qt, \ 
              ut2} = Pump[q, \ u2, \ n]; \[IndentingNewLine]{at, \ bt} = 
            WriteAs[U2, \ ut2, \ qt, \ n]; \[IndentingNewLine]U1a = \(-bt\)/
              qt; \[IndentingNewLine]U2 = 
            U2 - D*\((U1a /. n \[Rule] n + 1)\) + 
              U1a; \[IndentingNewLine]U1 = U1 + U1a; \[IndentingNewLine]u2 = 
            Denominator[
              Factor[U2]]\[IndentingNewLine]]; \[IndentingNewLine]N2 = \(-Dis[
              d2 /. n \[Rule] \(-n\), \ u2 /. n \[Rule] \(-n\), \ 
              n]\); \[IndentingNewLine]For[h = N2, \ 
          h \[LessEqual] 0, \ \(h++\), \[IndentingNewLine]q = 
            PolynomialGCD[u2, \ 
              d2 /. n \[Rule] n - h]; \[IndentingNewLine]{qt, \ ut2} = 
            Pump[q, \ u2, \ n]; \[IndentingNewLine]{at, \ bt} = 
            WriteAs[U2, \ ut2, \ qt, \ 
              n]; \[IndentingNewLine]U1a = \((bt/\((D*qt)\))\) /. 
              n \[Rule] n - 1; \[IndentingNewLine]U2 = 
            U2 - D*\((U1a /. n \[Rule] n + 1)\) + 
              U1a; \[IndentingNewLine]U1 = U1 + U1a; \[IndentingNewLine]u2 = 
            Denominator[
              Factor[U2]]\[IndentingNewLine]]; \[IndentingNewLine]v1 = 
          Numerator[Factor[U2]]; \[IndentingNewLine]v2 = 
          u2; \[IndentingNewLine]w1 = 
          PolynomialGCD[d1 /. n \[Rule] n - 1, \ v2]; \[IndentingNewLine]v2 = 
          v2/w1; \[IndentingNewLine]f1 = 
          d1/\((w1 /. n \[Rule] n + 1)\)*w1; \[IndentingNewLine]w2 = 
          PolynomialGCD[d2, \ v2]; \[IndentingNewLine]v2 = 
          v2/w2; \[IndentingNewLine]f2 = 
          d2/w2*\((w2 /. n \[Rule] n + 1)\); \[IndentingNewLine]F = 
          f1/f2; \[IndentingNewLine]V = 
          v1/v2; \[IndentingNewLine]Return[{U1, \ F, \ 
            V}]\[IndentingNewLine]]\)], "Input"],

Cell[BoxData[
    \(AboveZeroPole[R_, \ n_] := 
      Module[{RF, \ zeros, \ poles, \ max}, \[IndentingNewLine]RF = 
          Factor[R]; \[IndentingNewLine]zeros = 
          Solve[Numerator[RF] \[Equal] 0, \ n]; \[IndentingNewLine]If[
          Head[zeros] =!= 
            List, \[IndentingNewLine]zeros = {}\[IndentingNewLine]]; \
\[IndentingNewLine]poles = 
          Solve[Denominator[RF] \[Equal] 0, \ n]; \[IndentingNewLine]If[
          Head[poles] =!= 
            List, \[IndentingNewLine]poles = {}\[IndentingNewLine]]; \
\[IndentingNewLine]max = 
          Max[Select[
              n /. Select[
                  Flatten[{zeros, \ poles, \ {{n \[Rule] something}}}, \ 
                    1], \ Length[#] > 0 &], \ 
              NumberQ[#]\  && \ Im[#] \[Equal] 0 &]]; \[IndentingNewLine]If[
          max \[Equal] \(-\[Infinity]\), \[IndentingNewLine]Return[
            0], \[IndentingNewLine]Return[
            max + 1]\[IndentingNewLine]]\[IndentingNewLine]]\)], "Input"],

Cell[BoxData[
    \(Dterm[D_, \ U_, \ n0_, \ n_] := 
      Module[{U1, \ F, \ V, \ n1, \ \[Beta], \ t1, \ t2, \ 
          U2}, \[IndentingNewLine]{U1, \ F, \ V} = 
          Dcert[D, \ U, \ n]; \[IndentingNewLine]If[
          Factor[U1] \[Equal] 
            0, \[IndentingNewLine]Return[{0, \ {D, \ U, \ 
                n0}}]\[IndentingNewLine]]; \[IndentingNewLine]n1 = 
          Max[n0, \ AboveZeroPole[U1, \ n], \ AboveZeroPole[F, \ n], \ 
            AboveZeroPole[V, \ n]]; \[IndentingNewLine]\[Beta] = 
          Product[D /. n \[Rule] k, \ {k, \ n0, \ 
              n1 - 1}]; \[IndentingNewLine]t1 = {D, \ \[Beta]*U1, \ 
            n1}; \[IndentingNewLine]If[
          Factor[V] \[Equal] 
            0, \[IndentingNewLine]Return[{t1, \ 
              0}]\[IndentingNewLine]]; \[IndentingNewLine]U2 = \((U /. 
                n \[Rule] n1)\) - \((D /. n \[Rule] n1)\)*\((U1 /. 
                  n \[Rule] n1 + 1)\) + \((U1 /. 
                n \[Rule] 
                  n1)\); \[IndentingNewLine]t2 = {F, \ \[Beta]*\((U2 /. 
                    n \[Rule] n1)\)/\((V /. n \[Rule] n1)\)*V, \ 
            n1}; \[IndentingNewLine]Return[{t1, \ 
            t2}]\[IndentingNewLine]]\)], "Input"],

Cell[BoxData[
    \(DeMulti[F_, \ V_, \ n0_, \ n_] := 
      Module[{k}, \[IndentingNewLine]V*
          Product[F /. n \[Rule] k, \ {k, \ n0, \ 
              n - 1}]\[IndentingNewLine]]\)], "Input"],

Cell[BoxData[
    \(AlmostRNF[R_, \ x_] := 
      Module[{a, \ b, \ c, \ s, \ r, \ d, \ ignore, \ g, \ u, \ 
          v}, \[IndentingNewLine]{a, \ b, \ c} = 
          MixedNormalForm[Factor[R], \ x, \ ignore]; \[IndentingNewLine]{s, \ 
            r, \ d} = 
          MixedNormalForm[Factor[b/a], \ x, \ ignore]; \[IndentingNewLine]g = 
          PolynomialGCD[c, \ d]; \[IndentingNewLine]u = 
          c/g; \[IndentingNewLine]v = 
          d/g; \[IndentingNewLine]Return[{r, \ s, \ u, \ 
            v}]\[IndentingNewLine]]\)], "Input"],

Cell[BoxData[
    \(Multi[T_, \ n_] := 
      Module[{n0, \ R, \ r, \ s, \ u, \ v, \ W}, \[IndentingNewLine]n0 = 
          AboveZeroPole[T, \ n]; \[IndentingNewLine]R = 
          GetRatio[T, \ n]; \[IndentingNewLine]{r, \ s, \ u, \ v} = 
          AlmostRNF[R, \ n]; \[IndentingNewLine]W = 
          u/v*\((T /. n \[Rule] n0)\)/\((u/v /. 
                  n \[Rule] n0)\); \[IndentingNewLine]Return[{r/s, \ W, \ 
            n0}]\[IndentingNewLine]]\)], "Input"],

Cell[BoxData[
    \(AdditiveDecompositionGosper[T_, \ n_] := 
      Module[{T1, \ TM}, \[IndentingNewLine]T1 = 
          GosperSum[T, \ n]; \[IndentingNewLine]If[
          T1 === $Failed, \[IndentingNewLine]TM = 
            Multi[T, \ n]; \[IndentingNewLine]Return[
            Dterm[TM[\([1]\)], \ TM[\([2]\)], \ TM[\([3]\)], \ 
              n]], \[IndentingNewLine]Return[{T1, \ 
              0}]\[IndentingNewLine]]\[IndentingNewLine]]\)], "Input"],

Cell[BoxData[
    RowBox[{\(Dpol[F_, \ V_, \ n0_, \ n_]\), ":=", 
      RowBox[{"Module", "[", 
        RowBox[{\({SRaw, \ S, \ n1, \ \[Beta]}\), ",", "\[IndentingNewLine]", 
          
          RowBox[{
            RowBox[{"SRaw", "=", 
              StyleBox[\(MixedPoly[F*y[n + 1] - y[n] == V, \ y[n], \ {}]\),
                FormatType->StandardForm]}], 
            StyleBox[";",
              FormatType->StandardForm], 
            StyleBox["\[IndentingNewLine]",
              FormatType->StandardForm], 
            RowBox[{"If", "[", 
              RowBox[{\(Length[SRaw] > 0\), ",", "\[IndentingNewLine]", 
                RowBox[{"S", "=", 
                  RowBox[{
                    RowBox[{"Flatten", "[", "SRaw", 
                      StyleBox["]",
                        FormatType->StandardForm]}], 
                    StyleBox["[",
                      FormatType->StandardForm], 
                    StyleBox[\([1]\),
                      FormatType->StandardForm], 
                    StyleBox["]",
                      FormatType->StandardForm]}]}], 
                StyleBox[",",
                  FormatType->StandardForm], 
                StyleBox["\[IndentingNewLine]",
                  FormatType->StandardForm], 
                StyleBox[\(Return[0]\),
                  FormatType->StandardForm]}], 
              StyleBox["\[IndentingNewLine]",
                FormatType->StandardForm], "]"}], ";", 
            "\[IndentingNewLine]", \(n1 = Max[AboveZeroPole[S, \ n], \ n0]\), 
            ";", "\[IndentingNewLine]", \(\[Beta] = 
              Product[F /. n \[Rule] k, \ {k, \ n0, \ n1 - 1}]\), ";", 
            "\[IndentingNewLine]", \(Return[{F, \ \[Beta]*S, \ n1}]\)}]}], 
        "\[IndentingNewLine]", "]"}]}]], "Input"],

Cell[BoxData[
    \(SumOfTerms[D1_, \ U1_, \ n1_, \ D2_, \ U2_, \ n2_, \ n_] := 
      Module[{f1, \ f2, \ s1, \ s2, \ S, \ n3, \ k, \ G, \ 
          n4}, \[IndentingNewLine]{f1, \ f2, \ s1, \ s2} = 
          AlmostRNF[D1/D2, \ n]; \[IndentingNewLine]S = 
          s1/s2; \[IndentingNewLine]n3 = 
          Max[AboveZeroPole[S, \ n], \ n1, \ 
            n2]; \[IndentingNewLine]\[Alpha] = 
          Product[\((D1 /. n \[Rule] k)\)/\((S /. n \[Rule] n3)\), \ {k, \ 
              n1, \ n3 - 1}]; \[IndentingNewLine]\[Beta] = 
          Product[D2 /. n \[Rule] k, \ {k, \ n2, \ 
              n3 - 1}]; \[IndentingNewLine]G = \[Alpha]*S*U1 + \[Beta]*
              U2; \[IndentingNewLine]If[
          G \[Equal] 0, \[IndentingNewLine]Return[
            0]\[IndentingNewLine]]; \[IndentingNewLine]n4 = 
          Max[AboveZeroPole[G, \ n], \ n3]; \[IndentingNewLine]\[Gamma] = 
          Product[D2 /. n \[Rule] k, \ {k, \ n3, \ 
              n4 - 1}]; \[IndentingNewLine]Return[{D2, \ \[Gamma]*G, \ 
            n4}]\[IndentingNewLine]]\)], "Input"],

Cell[BoxData[
    \(HgAddDec[D_, \ U_, \ n0_, \ n_] := 
      Module[{U1, \ F, \ V, \ t1, \ t2, \ VF, \ 
          t3}, \[IndentingNewLine]{U1, \ F, \ V} = 
          Dcert[D, \ U, \ n]; \[IndentingNewLine]{t1, \ t2} = 
          Dterm[D, \ U, \ n0, \ n]; \[IndentingNewLine]VF = 
          Factor[V]; \[IndentingNewLine]If[
          Length[t2] \[Equal] 
              0\  || \ \(! \((PolynomialQ[Numerator[VF], \ n]\  && \ 
                  PolynomialQ[Denominator[VF], \ 
                    n])\)\), \[IndentingNewLine]Return[{t1, \ 
              t2}]\[IndentingNewLine]]; \[IndentingNewLine]t3 = 
          Dpol[t2[\([1]\)], \ t2[\([2]\)], \ t2[\([3]\)], \ 
            n]; \[IndentingNewLine]If[
          Length[t1] \[Equal] 
            0, \[IndentingNewLine]t1 = {1, \ 0, \ 
              0}\[IndentingNewLine]]; \[IndentingNewLine]If[
          Length[t3] \[Equal] 
            0, \[IndentingNewLine]Return[{t1, \ 
              t2}], \[IndentingNewLine]Return[{SumOfTerms[t1[\([1]\)], \ 
                t1[\([2]\)], \ t1[\([3]\)], \ t3[\([1]\)], \ t3[\([2]\)], \ 
                t3[\([3]\)], \ n], \ 
              0}]\[IndentingNewLine]]\[IndentingNewLine]]\)], "Input"],

Cell[BoxData[
    \(AdditiveDecomposition[T_, \ n_] := 
      Module[{D, \ U, \ n0}, \[IndentingNewLine]{D, \ U, \ n0} = 
          Multi[T, \ n]; \[IndentingNewLine]Return[
          HgAddDec[D, \ U, \ n0, \ n]]\[IndentingNewLine]]\)], "Input"]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{

Cell["Tests", "Subtitle"],

Cell[CellGroupData[{

Cell["Dis", "Section"],

Cell[CellGroupData[{

Cell[BoxData[
    \(Dis[y, \ y^2 - 1, \ y]\)], "Input"],

Cell[BoxData[
    \(1\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(Dis[y, \ y, \ y]\)], "Input"],

Cell[BoxData[
    \(0\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(Dis[1, \ y^2 - 1, \ y]\)], "Input"],

Cell[BoxData[
    \(\(-1\)\)], "Output"]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{

Cell["Pump", "Section"],

Cell[BoxData[
    \(ftestPump[x_] := x^2 + 3*x + 1\)], "Input"],

Cell[BoxData[
    \(gtestPump[x_] := 
      ftestPump[x]*\((x^9 + 3*x^2 - x + 2)\)*\((2*x - 3)\)\)], "Input"],

Cell[CellGroupData[{

Cell[BoxData[
    \({fttestPump, \ gttestPump} = 
      Pump[ftestPump[x], gtestPump[x], \ x]\)], "Input"],

Cell[BoxData[
    \({1 + 3\ x + 
        x\^2, \((\(-3\) + 2\ x)\)\ \((2 - x + 3\ x\^2 + x\^9)\)}\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(PolynomialRemainder[ftestPump[x], \ fttestPump, \ x]\)], "Input"],

Cell[BoxData[
    \(0\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(Factor[fttestPump*gttestPump] \[Equal] Factor[gtestPump[x]]\)], "Input"],

Cell[BoxData[
    \(True\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(PolynomialGCD[fttestPump, \ gttestPump, \ x]\)], "Input"],

Cell[BoxData[
    \(1\)], "Output"]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{

Cell["WriteAs", "Section"],

Cell[BoxData[
    \(U2testWriteAs[
        x_] := \(\((x^2 + 1)\)/\((x - 7)\)^2\)/\((x^2 + 7)\)\)], "Input"],

Cell[BoxData[
    \(ut2testWriteAs[x_] := \((x - 7)\)^2\)], "Input"],

Cell[BoxData[
    \(qttestWriteAs[x_] := x^2 + 7\)], "Input"],

Cell[CellGroupData[{

Cell[BoxData[
    \({attestWriteAs, \ bttestWriteAs} = 
      WriteAs[U2testWriteAs[x], \ ut2testWriteAs[x], \ qttestWriteAs[x], \ 
        x]\)], "Input"],

Cell[BoxData[
    \({79\/112 + \(3\ x\)\/112, \(-\(9\/112\)\) - \(3\ x\)\/112}\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(Factor[U2testWriteAs[x]] \[Equal] 
      Factor[attestWriteAs/ut2testWriteAs[x] + 
          bttestWriteAs/qttestWriteAs[x]]\)], "Input"],

Cell[BoxData[
    \(True\)], "Output"]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{

Cell["Dcert", "Section"],

Cell[BoxData[
    \(DexDterm1[x_] := 1/\((x + 2)\)\)], "Input"],

Cell[BoxData[
    \(UexDterm1[x_] := 1/\((x + 1)\) - 1/x\)], "Input"],

Cell[CellGroupData[{

Cell[BoxData[
    \(n0exDterm1 = 1\)], "Input"],

Cell[BoxData[
    \(1\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \({U1exDcert, \ FexDcert, \ VexDcert} = 
      Dcert[DexDterm1[x], \ UexDterm1[x], \ x]\)], "Input"],

Cell[BoxData[
    \({1 + 1\/x, 1\/\(2 + x\), 1}\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(U2exDcert = 
      UexDterm1[x] - DexDterm1[x]*\((U1exDcert /. x \[Rule] x + 1)\) + 
        U1exDcert\)], "Input"],

Cell[BoxData[
    \(1 + 1\/\(1 + x\) - \(1 + 1\/\(1 + x\)\)\/\(2 + x\)\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(Factor[FexDcert*\((VexDcert /. x \[Rule] x + 1)\)/VexDcert] \[Equal] 
      Factor[DexDterm1[x]*\((U2exDcert /. x \[Rule] x + 1)\)/
            U2exDcert]\)], "Input"],

Cell[BoxData[
    \(True\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(f1exDcert = Numerator[\ Factor[FexDcert]]\)], "Input"],

Cell[BoxData[
    \(1\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(f2exDcert = Denominator[Factor[FexDcert]]\)], "Input"],

Cell[BoxData[
    \(2 + x\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(v1exDcert = Numerator[Factor[VexDcert]]\)], "Input"],

Cell[BoxData[
    \(1\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(v2exDcert = Denominator[Factor[VexDcert]]\)], "Input"],

Cell[BoxData[
    \(1\)], "Output"]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{

Cell["AboveZeroPole", "Section"],

Cell[CellGroupData[{

Cell[BoxData[
    \(AboveZeroPole[\((x + 3)\)/\((x - 3)\), \ x]\)], "Input"],

Cell[BoxData[
    \(4\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(AboveZeroPole[0, \ x]\)], "Input"],

Cell[BoxData[
    \(0\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(AboveZeroPole[x^2 + 1, \ x]\)], "Input"],

Cell[BoxData[
    \(0\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(AboveZeroPole[\(x!\)*Binomial[2*x, \ x], \ x]\)], "Input"],

Cell[BoxData[
    \(Solve::"dinv" \(\(:\)\(\ \)\) 
      "The expression \!\(Binomial[\(\(\(\(2\\ x\)\), x\)\)]\) involves \
unknowns in more than one argument, so inverse functions cannot be used."\)], \
"Message"],

Cell[BoxData[
    \(0\)], "Output"]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{

Cell["Dterm & DeMulti", "Section"],

Cell[CellGroupData[{

Cell[BoxData[
    \({t1exDterm1, \ t2exDterm1} = 
      Dterm[DexDterm1[x], \ UexDterm1[x], \ n0exDterm1, \ x]\)], "Input"],

Cell[BoxData[
    \({{1\/\(2 + x\), 1 + 1\/x, 1}, {1\/\(2 + x\), 1, 1}}\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(T1exDterm1 = 
      Factor[DeMulti[t1exDterm1[\([1]\)], \ t1exDterm1[\([2]\)], \ 
          t1exDterm1[\([3]\)], \ x]]\)], "Input"],

Cell[BoxData[
    \(\(2\ \((1 + x)\)\)\/\(x\ Gamma[2 + x]\)\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(T2exDterm1 = 
      Factor[DeMulti[t2exDterm1[\([1]\)], \ t2exDterm1[\([2]\)], \ 
          t2exDterm1[\([3]\)], \ x]]\)], "Input"],

Cell[BoxData[
    \(2\/Gamma[2 + x]\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(\((T1exDterm1 \[Equal] \(2/x\)/\(x!\))\) /. x \[Rule] 17\)], "Input"],

Cell[BoxData[
    \(True\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(\((T2exDterm1 \[Equal] 2/\(\((x + 1)\)!\))\) /. x \[Rule] 17\)], "Input"],

Cell[BoxData[
    \(True\)], "Output"]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{

Cell["AlmostRNF", "Section"],

Cell[BoxData[
    \(RexRNF[x_] := \((x^2 - 1)\)/\((x^2 + 2*x)\)\)], "Input"],

Cell[CellGroupData[{

Cell[BoxData[
    \({zrexRNF, \ sexRNF, \ uexRNF, \ vexRNF} = 
      AlmostRNF[RexRNF[y], \ y]\)], "Input"],

Cell[BoxData[
    \({1, 1, 1, \((\(-1\) + y)\)\ \((1 + y)\)}\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \({Simplify[zrexRNF/sexRNF], \ Simplify[uexRNF/vexRNF]}\)], "Input"],

Cell[BoxData[
    \({1, 1\/\(\(-1\) + y\^2\)}\)], "Output"]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{

Cell["Multi", "Section"],

Cell[BoxData[
    \(TexDterm1[
        x_] := \((1/\((x + 1)\) - 1/x)\)*2/\(\((x + 1)\)!\)\)], "Input"],

Cell[CellGroupData[{

Cell[BoxData[
    \(TMexDterm1 = Multi[TexDterm1[x], \ x]\)], "Input"],

Cell[BoxData[
    \(InverseFunction::"ifun" \(\(:\)\(\ \)\) 
      "Inverse functions are being used. Values may be lost for multivalued \
inverses."\)], "Message"],

Cell[BoxData[
    \({1\/\(2 + x\), \(-\(1\/\(x\ \((1 + x)\)\)\)\), 1}\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(TMexDterm1[\([2]\)] \[Equal] Factor[1/\((x + 1)\) - 1/x]\)], "Input"],

Cell[BoxData[
    \(True\)], "Output"]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{

Cell["GosperSum", "Section"],

Cell[CellGroupData[{

Cell[BoxData[
    \(GosperSum[TexDterm1[x], \ {x, \ 0, \ n}]\)], "Input"],

Cell[BoxData[
    \($Failed\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(GosperSum[TexDterm1[x], \ x]\)], "Input"],

Cell[BoxData[
    \($Failed\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(GosperSum[x, \ {x, \ 0, \ n}]\)], "Input"],

Cell[BoxData[
    \(1\/2\ n\ \((1 + n)\)\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(GosperSum[x, \ x]\)], "Input"],

Cell[BoxData[
    \(1\/2\ \((\(-1\) + x)\)\ x\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(GosperSum[1, \ {x, \ 0, \ n}]\)], "Input"],

Cell[BoxData[
    \(1 + n\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(GosperSum[1, \ x]\)], "Input"],

Cell[BoxData[
    \(x\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(Simplify[GosperSum[q^x, \ {x, \ 0, \ n}]]\)], "Input"],

Cell[BoxData[
    \(\(\(-1\) + q\^\(1 + n\)\)\/\(\(-1\) + q\)\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(GosperSum[q^x, \ x]\)], "Input"],

Cell[BoxData[
    \(q\^x\/\(\(-1\) + q\)\)], "Output"]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{

Cell["AdditiveDecompositionGosper", "Section"],

Cell[CellGroupData[{

Cell[BoxData[
    \(AdditiveDecompositionGosper[TexDterm1[x], \ x]\)], "Input"],

Cell[BoxData[
    \(InverseFunction::"ifun" \(\(:\)\(\ \)\) 
      "Inverse functions are being used. Values may be lost for multivalued \
inverses."\)], "Message"],

Cell[BoxData[
    \({{1\/\(2 + x\), 1 + 1\/x, 1}, {1\/\(2 + x\), 1, 1}}\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(AdditiveDecompositionGosper[q^x, \ x]\)], "Input"],

Cell[BoxData[
    \({q\^x\/\(\(-1\) + q\), 0}\)], "Output"]
}, Open  ]],

Cell[BoxData[
    \(TexDterm2[x_] := 
      1/8*\((x + 3)\)*\((x + 2)\)*\((x + 
            4)\)*\(\(\(\((43*x + 35)\)/\((2*x + 1)\)\)/\((2*x + 3)\)\)/\((2*
                  x + 5)\)\)/\((2*x + 7)\)\)], "Input"],

Cell[CellGroupData[{

Cell[BoxData[
    \({T1MexDterm2, \ T2MexDterm2} = 
      AdditiveDecompositionGosper[TexDterm2[x], \ x]\)], "Input"],

Cell[BoxData[
    \({{1, \(-\(945\/\(2048\ \((1 + 2\ x)\)\)\)\) - 
          915\/\(1024\ \((3 + 2\ x)\)\) - 2265\/\(2048\ \((5 + 2\ x)\)\), 
        1\/2}, {1, \(457 + 86\ x\)\/\(128\ \((7 + 2\ x)\)\), 
        1\/2}}\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(T1exDterm2 = 
      Factor[DeMulti[T1MexDterm2[\([1]\)], \ T1MexDterm2[\([2]\)], \ 
          T1MexDterm2[\([3]\)], \ x]]\)], "Input"],

Cell[BoxData[
    \(\(-\(\(15\ \((251 + 460\ x + 168\ x\^2)\)\)\/\(256\ \((1 + 
                2\ x)\)\ \((3 + 2\ x)\)\ \((5 + 2\ x)\)\)\)\)\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(T2exDterm2 = 
      Factor[DeMulti[T2MexDterm2[\([1]\)], \ T2MexDterm2[\([2]\)], \ 
          T2MexDterm2[\([3]\)], \ x]]\)], "Input"],

Cell[BoxData[
    \(\(457 + 86\ x\)\/\(128\ \((7 + 2\ x)\)\)\)], "Output"]
}, Open  ]],

Cell[BoxData[
    \(TexMaple1[
        x_] := \((x^2 - 2*x - 1)\)*2^
            x/\((\((x + 1)\)*x^2*\(\((x + 3)\)!\))\)\)], "Input"],

Cell[CellGroupData[{

Cell[BoxData[
    \(AdditiveDecompositionGosper[TexMaple1[x], \ x]\)], "Input"],

Cell[BoxData[
    \(InverseFunction::"ifun" \(\(:\)\(\ \)\) 
      "Inverse functions are being used. Values may be lost for multivalued \
inverses."\)], "Message"],

Cell[BoxData[
    \({{2\/\(4 + x\), 1\/54 + \(1 + x\)\/\(12\ x\^2\), 
        1}, {2\/\(4 + x\), \(5 + 9\ x + x\^2\)\/\(54\ \((1 + x)\)\^2\), 
        1}}\)], "Output"]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{

Cell["MixedPoly", "Section"],

Cell[BoxData[
    RowBox[{\(ptestMixedPoly[x_]\), ":=", 
      StyleBox[\(\(MixedPoly[p[x + 2] - 2\ *p[x + 1] + p[x] == 0, \ 
            p[x], \ {}]\)[\([1]\)]\),
        FormatType->StandardForm]}]], "Input"],

Cell[CellGroupData[{

Cell[BoxData[
    \(ptestMixedPoly[x]\)], "Input"],

Cell[BoxData[
    \(C[1] + x\ C[2]\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(Factor[\((ptestMixedPoly[x] /. x \[Rule] x + 2)\) - 
          2*\((ptestMixedPoly[x] /. x \[Rule] x + 1)\) + 
          ptestMixedPoly[x]] \[Equal] 0\)], "Input"],

Cell[BoxData[
    \(True\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      RowBox[{"Flatten", "[", 
        StyleBox[\(MixedPoly[p[x + 2] - 2\ *p[x + 1] + p[x] == 0, \ 
            p[x], \ {}]\),
          FormatType->StandardForm], 
        StyleBox["]",
          FormatType->StandardForm]}], 
      StyleBox["[",
        FormatType->StandardForm], 
      StyleBox[\([1]\),
        FormatType->StandardForm], 
      StyleBox["]",
        FormatType->StandardForm]}]], "Input"],

Cell[BoxData[
    \(C[1] + x\ C[2]\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(MixedPoly[p[x] \[Equal] p[x] + x, \ p[x], \ {}]\)], "Input"],

Cell[BoxData[
    RowBox[{\(\[Infinity]::"indet"\), \(\(:\)\(\ \)\), "\<\"Indeterminate \
expression \\!\\(\\*InterpretationBox[\\(-\[Infinity]\\), \
DirectedInfinity[-1]] + \\*InterpretationBox[\\\"\[Infinity]\\\", \
DirectedInfinity[1]]\\) encountered.\"\>"}]], "Message"],

Cell[BoxData[
    RowBox[{\(Range::"range"\), \(\(:\)\(\ \)\), "\<\"Range specification in \
\\!\\(Range[\\(\\(0, \\*InterpretationBox[\\(-\[Infinity]\\), \
DirectedInfinity[-1]]\\)\\)]\\) is not a machine-size integer.\"\>"}]], \
"Message"],

Cell[BoxData[
    RowBox[{\(\[Infinity]::"indet"\), \(\(:\)\(\ \)\), "\<\"Indeterminate \
expression \\!\\(x\\^\\*InterpretationBox[\\(-\[Infinity]\\), \
DirectedInfinity[-1]]\\) encountered.\"\>"}]], "Message"],

Cell[BoxData[
    RowBox[{\(Range::"range"\), \(\(:\)\(\ \)\), "\<\"Range specification in \
\\!\\(Range[\\(\\(0, \\*InterpretationBox[\\(-\[Infinity]\\), \
DirectedInfinity[-1]]\\)\\)]\\) is not a machine-size integer.\"\>"}]], \
"Message"],

Cell[BoxData[
    \(Range::"range" \(\(:\)\(\ \)\) 
      "Range specification in \!\(Range[\(\(0, \(\(Solve`DirInf[\(\(-1\)\)]\)\
\)\)\)]\) is not a machine-size integer."\)], "Message"],

Cell[BoxData[
    \(General::"stop" \(\(:\)\(\ \)\) 
      "Further output of \!\(Range :: \"range\"\) will be suppressed during \
this calculation."\)], "Message"],

Cell[BoxData[
    \(Solve::"ifun" \(\(:\)\(\ \)\) 
      "Inverse functions are being used by \!\(Solve\), so some solutions may \
not be found."\)], "Message"],

Cell[BoxData[
    RowBox[{\(Table::"iterb"\), \(\(:\)\(\ \)\), "\<\"Iterator \
\\!\\({Private`i$2599, 0, \\*InterpretationBox[\\(-\[Infinity]\\), \
DirectedInfinity[-1]]}\\) does not have appropriate bounds.\"\>"}]], "Message"],

Cell[BoxData[
    RowBox[{\(Table::"iterb"\), \(\(:\)\(\ \)\), "\<\"Iterator \
\\!\\({Private`i$2599, 0, \\*InterpretationBox[\\(-\[Infinity]\\), \
DirectedInfinity[-1]]}\\) does not have appropriate bounds.\"\>"}]], "Message"],

Cell[BoxData[
    \(Select::"normal" \(\(:\)\(\ \)\) 
      "Nonatomic expression expected at position \!\(1\) in \
\!\(Select[\(\(False, \(\(\(\(FreeQ[\(\(#1, Private`a$2598\)\)]\)\) \
&\)\)\)\)]\)."\)], "Message"],

Cell[BoxData[
    RowBox[{\(Table::"iterb"\), \(\(:\)\(\ \)\), "\<\"Iterator \
\\!\\({Private`i$2600, 0, \\*InterpretationBox[\\(-\[Infinity]\\), \
DirectedInfinity[-1]]}\\) does not have appropriate bounds.\"\>"}]], "Message"],

Cell[BoxData[
    \(General::"stop" \(\(:\)\(\ \)\) 
      "Further output of \!\(Table :: \"iterb\"\) will be suppressed during \
this calculation."\)], "Message"],

Cell[BoxData[
    RowBox[{\(Table::"itform"\), \(\(:\)\(\ \)\), "\<\"Argument \\!\\(\\(\\((\
\\(\\(\\(Coefficient[\\(\\(Private`lhs$2599, #1\\)\\)]\\)\\) \
&\\))\\)\\)[\\(\\({Private`i$2600, 0, \
\\*InterpretationBox[\\(-\[Infinity]\\), DirectedInfinity[-1]]}\\)\\)]\\) at \
position \\!\\(2\\) does not have the correct form for an iterator.\"\>"}]], \
"Message"],

Cell[BoxData[
    RowBox[{\(Table::"itform"\), \(\(:\)\(\ \)\), "\<\"Argument \\!\\(\\(\\((\
\\(\\(\\(Exponent[\\(\\(#1, x\\)\\)]\\)\\) \
&\\))\\)\\)[\\(\\(\\(\\((\\(\\(\\(Coefficient[\\(\\(Private`lhs$2599, \
#1\\)\\)]\\)\\) &\\))\\)\\)[\\(\\({Private`i$2600, 0, \
\\*InterpretationBox[\\(-\[Infinity]\\), DirectedInfinity[-1]]}\\)\\)]\\)\\)]\
\\) at position \\!\\(2\\) does not have the correct form for an \
iterator.\"\>"}]], "Message"],

Cell[BoxData[
    \(Coefficient::"ivar" \(\(:\)\(\ \)\) 
      "\!\(0\) is not a valid variable."\)], "Message"],

Cell[BoxData[
    \({}\)], "Output"]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{

Cell["Dpol", "Section"],

Cell[BoxData[
    \(TtestDpol[x_] := x^2\)], "Input"],

Cell[CellGroupData[{

Cell[BoxData[
    \(TMtestDpol = Multi[TtestDpol[x], \ x]\)], "Input"],

Cell[BoxData[
    \({1, x\^2, 1}\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(T1MtestDpol = 
      Dpol[TMtestDpol[\([1]\)], \ TMtestDpol[\([2]\)], \ 
        TMtestDpol[\([3]\)], \ x]\)], "Input"],

Cell[BoxData[
    \({1, 1\/6\ \((\(-1\) + x)\)\ x\ \((\(-1\) + 2\ x)\) + C[1], 
      1}\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(T1testDpol = 
      DeMulti[T1MtestDpol[\([1]\)], \ T1MtestDpol[\([2]\)], \ 
        T1MtestDpol[\([3]\)], \ x]\)], "Input"],

Cell[BoxData[
    \(1\/6\ \((\(-1\) + x)\)\ x\ \((\(-1\) + 2\ x)\) + C[1]\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(Factor[\((T1testDpol /. x \[Rule] x + 1)\) - T1testDpol]\)], "Input"],

Cell[BoxData[
    \(x\^2\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(Dpol[DexDterm1[x], \ UexDterm1[x], \ n0exDterm1, \ x]\)], "Input"],

Cell[BoxData[
    \(0\)], "Output"]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{

Cell["SumOfTerms", "Section"],

Cell[BoxData[
    \(T1testSOT[x_] := x^2*\(x!\)/\((x - 3)\)\)], "Input"],

Cell[CellGroupData[{

Cell[BoxData[
    \(T1MtestSOT = Multi[T1testSOT[x], \ x]\)], "Input"],

Cell[BoxData[
    \(InverseFunction::"ifun" \(\(:\)\(\ \)\) 
      "Inverse functions are being used. Values may be lost for multivalued \
inverses."\)], "Message"],

Cell[BoxData[
    \({\(-3\) + x, \((\(-2\) + x)\)\ \((\(-1\) + x)\)\ x\^3, 4}\)], "Output"]
}, Open  ]],

Cell[BoxData[
    \(T2testSOT[x_] := T1testSOT[x]*x/\((x + 1)\)\)], "Input"],

Cell[CellGroupData[{

Cell[BoxData[
    \(T2MtestSOT = Multi[T2testSOT[x], \ x]\)], "Input"],

Cell[BoxData[
    \(InverseFunction::"ifun" \(\(:\)\(\ \)\) 
      "Inverse functions are being used. Values may be lost for multivalued \
inverses."\)], "Message"],

Cell[BoxData[
    \({\(-3\) + x, \(\((\(-2\) + x)\)\ \((\(-1\) + x)\)\ x\^4\)\/\(1 + x\), 
      4}\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(T12MtestSOT = 
      SumOfTerms[T1MtestSOT[\([1]\)], \ T1MtestSOT[\([2]\)], \ 
        T1MtestSOT[\([3]\)], \ T2MtestSOT[\([1]\)], \ T2MtestSOT[\([2]\)], \ 
        T2MtestSOT[\([3]\)], \ x]\)], "Input"],

Cell[BoxData[
    \({\(-3\) + 
        x, \((\(-2\) + x)\)\ \((\(-1\) + 
              x)\)\ x\^3 + \(\((\(-2\) + x)\)\ \((\(-1\) + x)\)\ x\^4\)\/\(1 \
+ x\), 4}\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(T12testSOT = 
      Factor[DeMulti[T12MtestSOT[\([1]\)], \ T12MtestSOT[\([2]\)], \ 
          T12MtestSOT[\([3]\)], \ x]]\)], "Input"],

Cell[BoxData[
    \(\(\((\(-2\) + x)\)\ \((\(-1\) + x)\)\ x\^3\ \((1 + 2\ x)\)\ \(\((\(-4\) \
+ x)\)!\)\)\/\(1 + x\)\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(T12testSOT == T1testSOT[x] + T2testSOT[x] /. x \[Rule] 17\)], "Input"],

Cell[BoxData[
    \(True\)], "Output"]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{

Cell["HgAddDec", "Section"],

Cell[CellGroupData[{

Cell[BoxData[
    \(HgAddDec[DexDterm1[x], \ UexDterm1[x], \ n0exDterm1, \ x]\)], "Input"],

Cell[BoxData[
    \({{1\/\(2 + x\), 1 + 1\/x, 1}, {1\/\(2 + x\), 1, 1}}\)], "Output"]
}, Open  ]],

Cell[BoxData[
    \(DexHAD[x_] := x^2/\((x^2 + x + 1)\)\)], "Input"],

Cell[BoxData[
    \(UexHAD[x_] := \(1/x\)/\((x + 1)\)\)], "Input"],

Cell[CellGroupData[{

Cell[BoxData[
    \(n0exHAD = 1\)], "Input"],

Cell[BoxData[
    \(1\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \({T1MextHAD, \ T2MextHAD} = 
      HgAddDec[DexHAD[x], \ UexHAD[x], \ n0exHAD, \ x]\)], "Input"],

Cell[BoxData[
    \({{\(x\^2\ \((1 - 2\ x + x\^2)\)\)\/\(\((1 + x + x\^2)\)\ \((1 - 2\ \((1 \
+ x)\) + \((1 + x)\)\^2)\)\), 
        1\/21\ \((\(-\(1\/\((\(-1\) + x)\)\^2\)\) - 
                1\/x)\)\ \((\(-1\) + x)\)\^2 - 
          1\/21\ \((\(-2\) + x)\)\ \((1 - x + x\^2)\), 3}, 0}\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(Factor[T1MextHAD[\([1]\)]]\)], "Input"],

Cell[BoxData[
    \(\((\(-1\) + x)\)\^2\/\(1 + x + x\^2\)\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(Factor[T1MextHAD[\([2]\)]]\)], "Input"],

Cell[BoxData[
    \(\(-\(\(\((\(-1\) + x)\)\^2\ \((1 - x + 
                x\^2)\)\)\/\(21\ x\)\)\)\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(Factor[\(-1\)/21*\((x^4 - 3*x^3 + 4*x^2 - 3*x + 1)\)/x]\)], "Input"],

Cell[BoxData[
    \(\(-\(\(\((\(-1\) + x)\)\^2\ \((1 - x + 
                x\^2)\)\)\/\(21\ x\)\)\)\)], "Output"]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{

Cell["AdditiveDecomposition", "Section"],

Cell[CellGroupData[{

Cell[BoxData[
    \(AdditiveDecomposition[TexDterm1[x], \ x]\)], "Input"],

Cell[BoxData[
    \(InverseFunction::"ifun" \(\(:\)\(\ \)\) 
      "Inverse functions are being used. Values may be lost for multivalued \
inverses."\)], "Message"],

Cell[BoxData[
    \({{1\/\(2 + x\), 1 + 1\/x, 1}, {1\/\(2 + x\), 1, 1}}\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \({T1MtestAD, \ T2MtestAD} = AdditiveDecomposition[q^x, \ x]\)], "Input"],

Cell[BoxData[
    \(Solve::"ifun" \(\(:\)\(\ \)\) 
      "Inverse functions are being used by \!\(Solve\), so some solutions may \
not be found."\)], "Message"],

Cell[BoxData[
    \({{q, 1\/\(\(-1\) + q\), 0}, 0}\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(DeMulti[T1MtestAD[\([1]\)], \ T1MtestAD[\([2]\)], \ 
      T1MtestAD[\([3]\)], \ x]\)], "Input"],

Cell[BoxData[
    \(q\^x\/\(\(-1\) + q\)\)], "Output"]
}, Open  ]]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{

Cell["Examples", "Subtitle"],

Cell[CellGroupData[{

Cell["\<\
Rational Normal Forms and Minimal Decomposition of Hypergeometric Terms, \
example 1 (non-summable)\
\>", "Section"],

Cell[BoxData[
    \(Clear[T, \ t1, \ t2, \ T1, \ T2]\)], "Input"],

Cell[CellGroupData[{

Cell[BoxData[
    \(T = \((1/\((n + 1)\) - 1/n)\)*2/\(\((n + 1)\)!\)\)], "Input"],

Cell[BoxData[
    \(\(2\ \((\(-\(1\/n\)\) + 1\/\(1 + n\))\)\)\/\(\((1 + n)\)!\)\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \({t1, \ t2} = AdditiveDecomposition[T, \ n]\)], "Input"],

Cell[BoxData[
    \(InverseFunction::"ifun" \(\(:\)\(\ \)\) 
      "Inverse functions are being used. Values may be lost for multivalued \
inverses."\)], "Message"],

Cell[BoxData[
    \({{1\/\(2 + n\), 1 + 1\/n, 1}, {1\/\(2 + n\), 1, 1}}\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(T1 = DeMulti[t1[\([1]\)], \ t1[\([2]\)], \ t1[\([3]\)], \ n]\)], "Input"],

Cell[BoxData[
    \(\(2\ \((1 + 1\/n)\)\)\/Gamma[2 + n]\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(T2 = DeMulti[t2[\([1]\)], \ t2[\([2]\)], \ t2[\([3]\)], \ n]\)], "Input"],

Cell[BoxData[
    \(2\/Gamma[2 + n]\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(FactorialSimplify[T1] \[Equal] 
      FactorialSimplify[\(2/n\)/\(n!\)]\)], "Input"],

Cell[BoxData[
    \(True\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(FactorialSimplify[T2] \[Equal] 
      FactorialSimplify[2/\(\((n + 1)\)!\)]\)], "Input"],

Cell[BoxData[
    \(True\)], "Output"]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{

Cell["\<\
Rational Normal Forms and Minimal Decomposition of Hypergeometric Terms, \
example 2 (non-summable)\
\>", "Section"],

Cell[BoxData[
    \(Clear[T, \ t1, \ t2, \ T1, \ T2]\)], "Input"],

Cell[CellGroupData[{

Cell[BoxData[
    \(T = 
      1/8*\((n + 3)\)*\((n + 2)\)*\((n + 
            4)\)*\(\(\(\((43*n + 35)\)/\((2*n + 1)\)\)/\((2*n + 3)\)\)/\((2*
                  n + 5)\)\)/\((2*n + 7)\)\)], "Input"],

Cell[BoxData[
    \(\(\((2 + n)\)\ \((3 + n)\)\ \((4 + n)\)\ \((35 + 43\ n)\)\)\/\(8\ \((1 \
+ 2\ n)\)\ \((3 + 2\ n)\)\ \((5 + 2\ n)\)\ \((7 + 2\ n)\)\)\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \({t1, \ t2} = AdditiveDecomposition[T, \ n]\)], "Input"],

Cell[BoxData[
    \({{1, \(-\(945\/\(2048\ \((1 + 2\ n)\)\)\)\) - 
          915\/\(1024\ \((3 + 2\ n)\)\) - 2265\/\(2048\ \((5 + 2\ n)\)\), 
        1\/2}, {1, \(457 + 86\ n\)\/\(128\ \((7 + 2\ n)\)\), 
        1\/2}}\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(T1 = DeMulti[t1[\([1]\)], \ t1[\([2]\)], \ t1[\([3]\)], \ n]\)], "Input"],

Cell[BoxData[
    \(\(-\(945\/\(2048\ \((1 + 2\ n)\)\)\)\) - 
      915\/\(1024\ \((3 + 2\ n)\)\) - 
      2265\/\(2048\ \((5 + 2\ n)\)\)\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(T2 = DeMulti[t2[\([1]\)], \ t2[\([2]\)], \ t2[\([3]\)], \ n]\)], "Input"],

Cell[BoxData[
    \(\(457 + 86\ n\)\/\(128\ \((7 + 2\ n)\)\)\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(FactorialSimplify[T1] \[Equal] 
      FactorialSimplify[\(-15\)/
            256*\(\(\((168*n^2 + 460*n + 251)\)/\((2*n + 1)\)\)/\((2*n + 
                  3)\)\)/\((2*n + 5)\)]\)], "Input"],

Cell[BoxData[
    \(True\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(FactorialSimplify[T2] \[Equal] 
      FactorialSimplify[\((86*n + 457)\)/\((256*n + 896)\)]\)], "Input"],

Cell[BoxData[
    \(True\)], "Output"]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{

Cell["\<\
Rational Normal Forms and Minimal Decomposition of Hypergeometric Terms, \
example 3 (summable)\
\>", "Section"],

Cell[BoxData[
    \(Clear[TM, \ t1, \ t2]\)], "Input"],

Cell[CellGroupData[{

Cell[BoxData[
    \(TM = {n^2/\((n^2 + n + 1)\), \ \(1/n\)/\((n + 1)\), \ 1}\)], "Input"],

Cell[BoxData[
    \({n\^2\/\(1 + n + n\^2\), 1\/\(n\ \((1 + n)\)\), 1}\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \({t1, \ t2} = 
      HgAddDec[TM[\([1]\)], \ TM[\([2]\)], \ TM[\([3]\)], \ n]\)], "Input"],

Cell[BoxData[
    \({{\(n\^2\ \((1 - 2\ n + n\^2)\)\)\/\(\((1 + n + n\^2)\)\ \((1 - 2\ \((1 \
+ n)\) + \((1 + n)\)\^2)\)\), 
        1\/21\ \((\(-\(1\/\((\(-1\) + n)\)\^2\)\) - 
                1\/n)\)\ \((\(-1\) + n)\)\^2 - 
          1\/21\ \((\(-2\) + n)\)\ \((1 - n + n\^2)\), 3}, 0}\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(FactorialSimplify[t1[\([1]\)]] \[Equal] 
      FactorialSimplify[\((n - 1)\)^2/\((n^2 + n + 1)\)]\)], "Input"],

Cell[BoxData[
    \(True\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(FactorialSimplify[t1[\([2]\)]] \[Equal] 
      FactorialSimplify[\(-1\)/21*\((n^4 - 3*n^3 + 4*n^2 - 3*n + 1)\)/
            n]\)], "Input"],

Cell[BoxData[
    \(True\)], "Output"]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{

Cell["\<\
Minimal Decomposition of Indefinite Hypergeometric Sums, example 2 (summable)\
\
\>", "Section"],

Cell[BoxData[
    \(Clear[T, \ t1, \ t2, \ T1]\)], "Input"],

Cell[CellGroupData[{

Cell[BoxData[
    \(T = \((1/\((n + 1)\) - 1/n - 1)\)*2/\(\((n + 1)\)!\)\)], "Input"],

Cell[BoxData[
    \(\(2\ \((\(-1\) - 1\/n + 1\/\(1 + n\))\)\)\/\(\((1 + n)\)!\)\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \({t1, \ t2} = AdditiveDecomposition[T, \ n]\)], "Input"],

Cell[BoxData[
    \(InverseFunction::"ifun" \(\(:\)\(\ \)\) 
      "Inverse functions are being used. Values may be lost for multivalued \
inverses."\)], "Message"],

Cell[BoxData[
    \({{1\/\(2 + n\), 1 + 1\/n, 1}, 0}\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(T1 = DeMulti[t1[\([1]\)], \ t1[\([2]\)], \ t1[\([3]\)], \ n]\)], "Input"],

Cell[BoxData[
    \(\(2\ \((1 + 1\/n)\)\)\/Gamma[2 + n]\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(FactorialSimplify[\((T1 /. n \[Rule] n + 1)\) - T1] \[Equal] 
      FactorialSimplify[T]\)], "Input"],

Cell[BoxData[
    \(True\)], "Output"]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{

Cell["\<\
Minimal Decomposition of Indefinite Hypergeometric Sums, example 3 \
(non-summable)\
\>", "Section"],

Cell[BoxData[
    \(Clear[T, \ t1, \ t2, \ T1, \ T2]\)], "Input"],

Cell[CellGroupData[{

Cell[BoxData[
    \(T = n^2/Binomial[2*n, \ n]\)], "Input"],

Cell[BoxData[
    \(n\^2\/Binomial[2\ n, n]\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \({t1, \ t2} = AdditiveDecomposition[T, \ n]\)], "Input"],

Cell[BoxData[
    \(Solve::"dinv" \(\(:\)\(\ \)\) 
      "The expression \!\(Binomial[\(\(\(\(2\\ n\)\), n\)\)]\) involves \
unknowns in more than one argument, so inverse functions cannot be used."\)], \
"Message"],

Cell[BoxData[
    \({{1, 0, 0}, {\(1 + n\)\/\(2\ \((1 + 2\ n)\)\), n\^2\/2, 1}}\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(FactorialSimplify[t2[\([1]\)]] \[Equal] 
      FactorialSimplify[\((1/4*n + 1/4)\)/\((n + 1/2)\)]\)], "Input"],

Cell[BoxData[
    \(True\)], "Output"]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{

Cell["\<\
Mitja, example 1 (non-summable)\
\>", "Section"],

Cell[BoxData[
    \(Clear[T, \ t1, \ t2, \ T1, \ T2]\)], "Input"],

Cell[CellGroupData[{

Cell[BoxData[
    \(T = \((1/\((n + 1)\) - 1/n)\)*1/n^5\)], "Input"],

Cell[BoxData[
    \(\(\(-\(1\/n\)\) + 1\/\(1 + n\)\)\/n\^5\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \({t1, \ t2} = AdditiveDecomposition[T, \ n]\)], "Input"],

Cell[BoxData[
    \({{1, \(1 - n + n\^2 - n\^3 + n\^4 - n\^5\)\/n\^6, 
        2}, {1, \(\(-1\) - 2\ n - 4\ n\^2 - 3\ n\^3 - n\^4\)\/\((1 + n)\)\^6, 
        2}}\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(T1 = DeMulti[t1[\([1]\)], \ t1[\([2]\)], \ t1[\([3]\)], \ n]\)], "Input"],

Cell[BoxData[
    \(\(1 - n + n\^2 - n\^3 + n\^4 - n\^5\)\/n\^6\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(T2 = DeMulti[t2[\([1]\)], \ t2[\([2]\)], \ t2[\([3]\)], \ n]\)], "Input"],

Cell[BoxData[
    \(\(\(-1\) - 2\ n - 4\ n\^2 - 3\ n\^3 - n\^4\)\/\((1 + n)\)\^6\)], \
"Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(FactorialSimplify[\((T1 /. n \[Rule] n + 1)\) - T1 + T2] \[Equal] 
      FactorialSimplify[T]\)], "Input"],

Cell[BoxData[
    \(True\)], "Output"]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{

Cell["\<\
Mitja, example 2 (non-summable)\
\>", "Section"],

Cell[BoxData[
    \(Clear[T, \ t1, \ t2, \ T1, \ T2]\)], "Input"],

Cell[CellGroupData[{

Cell[BoxData[
    \(T = \((n + 1)\)*\((n + 
            2)\)*\(\(\((n + 3)\)/\((2*n + 1)\)\)/\((2*n + 2)\)\)/\((2*n + 
              3)\)\)], "Input"],

Cell[BoxData[
    \(\(\((1 + n)\)\ \((2 + n)\)\ \((3 + n)\)\)\/\(\((1 + 2\ n)\)\ \((2 + 2\ \
n)\)\ \((3 + 2\ n)\)\)\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \({t1, \ t2} = AdditiveDecomposition[T, \ n]\)], "Input"],

Cell[BoxData[
    \({{1, \(-\(15\/\(16\ \((1 + 2\ n)\)\)\)\), 
        1\/2}, {1, \(9 + 2\ n\)\/\(8\ \((3 + 2\ n)\)\), 1\/2}}\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(T1 = DeMulti[t1[\([1]\)], \ t1[\([2]\)], \ t1[\([3]\)], \ n]\)], "Input"],

Cell[BoxData[
    \(\(-\(15\/\(16\ \((1 + 2\ n)\)\)\)\)\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(T2 = DeMulti[t2[\([1]\)], \ t2[\([2]\)], \ t2[\([3]\)], \ n]\)], "Input"],

Cell[BoxData[
    \(\(9 + 2\ n\)\/\(8\ \((3 + 2\ n)\)\)\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(FactorialSimplify[\((T1 /. n \[Rule] n + 1)\) - T1 + T2] \[Equal] 
      FactorialSimplify[T]\)], "Input"],

Cell[BoxData[
    \(True\)], "Output"]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{

Cell["Mitja, example 3 (summable)", "Section"],

Cell[BoxData[
    \(Clear[T, \ t1, \ t2, \ T1, \ T2]\)], "Input"],

Cell[CellGroupData[{

Cell[BoxData[
    \(T = \(n!\)/\(\((2*n)\)!!\)\)], "Input"],

Cell[BoxData[
    \(\(n!\)\/\(\((2\ n)\)!!\)\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \({t1, \ t2} = AdditiveDecomposition[T, \ n]\)], "Input"],

Cell[BoxData[
    \(InverseFunction::"ifun" \(\(:\)\(\ \)\) 
      "Inverse functions are being used. Values may be lost for multivalued \
inverses."\)], "Message"],

Cell[BoxData[
    \(InverseFunction::"ifun" \(\(:\)\(\ \)\) 
      "Inverse functions are being used. Values may be lost for multivalued \
inverses."\)], "Message"],

Cell[BoxData[
    \({{1\/2, \(-2\), 0}, 0}\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(T1 = DeMulti[t1[\([1]\)], \ t1[\([2]\)], \ t1[\([3]\)], \ n]\)], "Input"],

Cell[BoxData[
    \(\(-2\^\(1 - n\)\)\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(FactorialSimplify[T1] \[Equal] 
      FactorialSimplify[GosperSum[T, \ n]]\)], "Input"],

Cell[BoxData[
    \(True\)], "Output"]
}, Open  ]]
}, Closed]]
}, Closed]]
},
FrontEndVersion->"4.2 for Microsoft Windows",
ScreenRectangle->{{0, 1280}, {0, 941}},
WindowSize->{1117, 788},
WindowMargins->{{12, Automatic}, {Automatic, 11}},
PrintingCopies->1,
PrintingPageRange->{Automatic, Automatic}
]

(*******************************************************************
Cached data follows.  If you edit this Notebook file directly, not
using Mathematica, you must remove the line containing CacheID at
the top of  the file.  The cache data will then be recreated when
you save this file from within Mathematica.
*******************************************************************)

(*CellTagsOutline
CellTagsIndex->{}
*)

(*CellTagsIndex
CellTagsIndex->{}
*)

(*NotebookFileOutline
Notebook[{
Cell[1754, 51, 271, 6, 71, "Text"],

Cell[CellGroupData[{
Cell[2050, 61, 27, 0, 64, "Subtitle"],

Cell[CellGroupData[{
Cell[2102, 65, 22, 0, 59, "Section"],
Cell[2127, 67, 66, 1, 30, "Input"],

Cell[CellGroupData[{
Cell[2218, 72, 114, 2, 30, "Input"],
Cell[2335, 76, 145, 2, 70, "Print"]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{
Cell[2529, 84, 28, 0, 39, "Section"],
Cell[2560, 86, 551, 9, 210, "Input"],
Cell[3114, 97, 493, 9, 230, "Input"],
Cell[3610, 108, 466, 10, 110, "Input"],
Cell[4079, 120, 2917, 51, 970, "Input"],
Cell[6999, 173, 991, 19, 330, "Input"],
Cell[7993, 194, 1209, 22, 310, "Input"],
Cell[9205, 218, 200, 4, 70, "Input"],
Cell[9408, 224, 542, 10, 170, "Input"],
Cell[9953, 236, 466, 8, 150, "Input"],
Cell[10422, 246, 456, 8, 170, "Input"],
Cell[10881, 256, 1774, 38, 210, "Input"],
Cell[12658, 296, 1055, 18, 290, "Input"],
Cell[13716, 316, 1186, 22, 330, "Input"],
Cell[14905, 340, 245, 4, 90, "Input"]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{
Cell[15199, 350, 25, 0, 53, "Subtitle"],

Cell[CellGroupData[{
Cell[15249, 354, 22, 0, 59, "Section"],

Cell[CellGroupData[{
Cell[15296, 358, 55, 1, 30, "Input"],
Cell[15354, 361, 35, 1, 70, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[15426, 367, 49, 1, 30, "Input"],
Cell[15478, 370, 35, 1, 70, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[15550, 376, 55, 1, 30, "Input"],
Cell[15608, 379, 40, 1, 70, "Output"]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{
Cell[15697, 386, 23, 0, 39, "Section"],
Cell[15723, 388, 63, 1, 30, "Input"],
Cell[15789, 391, 109, 2, 30, "Input"],

Cell[CellGroupData[{
Cell[15923, 397, 106, 2, 30, "Input"],
Cell[16032, 401, 111, 2, 70, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[16180, 408, 85, 1, 30, "Input"],
Cell[16268, 411, 35, 1, 70, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[16340, 417, 92, 1, 30, "Input"],
Cell[16435, 420, 38, 1, 70, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[16510, 426, 77, 1, 30, "Input"],
Cell[16590, 429, 35, 1, 70, "Output"]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{
Cell[16674, 436, 26, 0, 39, "Section"],
Cell[16703, 438, 108, 2, 30, "Input"],
Cell[16814, 442, 68, 1, 30, "Input"],
Cell[16885, 445, 61, 1, 30, "Input"],

Cell[CellGroupData[{
Cell[16971, 450, 155, 3, 30, "Input"],
Cell[17129, 455, 92, 1, 70, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[17258, 461, 157, 3, 30, "Input"],
Cell[17418, 466, 38, 1, 70, "Output"]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{
Cell[17505, 473, 24, 0, 39, "Section"],
Cell[17532, 475, 63, 1, 30, "Input"],
Cell[17598, 478, 69, 1, 30, "Input"],

Cell[CellGroupData[{
Cell[17692, 483, 47, 1, 30, "Input"],
Cell[17742, 486, 35, 1, 70, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[17814, 492, 118, 2, 30, "Input"],
Cell[17935, 496, 61, 1, 70, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[18033, 502, 135, 3, 30, "Input"],
Cell[18171, 507, 84, 1, 70, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[18292, 513, 187, 3, 30, "Input"],
Cell[18482, 518, 38, 1, 70, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[18557, 524, 74, 1, 30, "Input"],
Cell[18634, 527, 35, 1, 70, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[18706, 533, 74, 1, 30, "Input"],
Cell[18783, 536, 39, 1, 70, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[18859, 542, 72, 1, 30, "Input"],
Cell[18934, 545, 35, 1, 70, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[19006, 551, 74, 1, 30, "Input"],
Cell[19083, 554, 35, 1, 70, "Output"]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{
Cell[19167, 561, 32, 0, 39, "Section"],

Cell[CellGroupData[{
Cell[19224, 565, 76, 1, 30, "Input"],
Cell[19303, 568, 35, 1, 70, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[19375, 574, 54, 1, 30, "Input"],
Cell[19432, 577, 35, 1, 70, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[19504, 583, 60, 1, 30, "Input"],
Cell[19567, 586, 35, 1, 70, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[19639, 592, 78, 1, 30, "Input"],
Cell[19720, 595, 215, 4, 70, "Message"],
Cell[19938, 601, 35, 1, 70, "Output"]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{
Cell[20022, 608, 34, 0, 39, "Section"],

Cell[CellGroupData[{
Cell[20081, 612, 123, 2, 30, "Input"],
Cell[20207, 616, 85, 1, 70, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[20329, 622, 151, 3, 30, "Input"],
Cell[20483, 627, 73, 1, 70, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[20593, 633, 151, 3, 30, "Input"],
Cell[20747, 638, 49, 1, 70, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[20833, 644, 89, 1, 30, "Input"],
Cell[20925, 647, 38, 1, 70, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[21000, 653, 93, 1, 30, "Input"],
Cell[21096, 656, 38, 1, 70, "Output"]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{
Cell[21183, 663, 28, 0, 39, "Section"],
Cell[21214, 665, 76, 1, 30, "Input"],

Cell[CellGroupData[{
Cell[21315, 670, 107, 2, 30, "Input"],
Cell[21425, 674, 74, 1, 70, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[21536, 680, 86, 1, 30, "Input"],
Cell[21625, 683, 59, 1, 70, "Output"]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{
Cell[21733, 690, 24, 0, 39, "Section"],
Cell[21760, 692, 103, 2, 30, "Input"],

Cell[CellGroupData[{
Cell[21888, 698, 70, 1, 30, "Input"],
Cell[21961, 701, 164, 3, 70, "Message"],
Cell[22128, 706, 83, 1, 70, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[22248, 712, 89, 1, 30, "Input"],
Cell[22340, 715, 38, 1, 70, "Output"]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{
Cell[22427, 722, 28, 0, 39, "Section"],

Cell[CellGroupData[{
Cell[22480, 726, 73, 1, 30, "Input"],
Cell[22556, 729, 41, 1, 70, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[22634, 735, 61, 1, 30, "Input"],
Cell[22698, 738, 41, 1, 70, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[22776, 744, 62, 1, 30, "Input"],
Cell[22841, 747, 54, 1, 70, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[22932, 753, 50, 1, 30, "Input"],
Cell[22985, 756, 59, 1, 70, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[23081, 762, 62, 1, 30, "Input"],
Cell[23146, 765, 39, 1, 70, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[23222, 771, 50, 1, 30, "Input"],
Cell[23275, 774, 35, 1, 70, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[23347, 780, 74, 1, 30, "Input"],
Cell[23424, 783, 75, 1, 70, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[23536, 789, 52, 1, 30, "Input"],
Cell[23591, 792, 54, 1, 70, "Output"]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{
Cell[23694, 799, 46, 0, 39, "Section"],

Cell[CellGroupData[{
Cell[23765, 803, 79, 1, 30, "Input"],
Cell[23847, 806, 164, 3, 70, "Message"],
Cell[24014, 811, 85, 1, 70, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[24136, 817, 70, 1, 30, "Input"],
Cell[24209, 820, 59, 1, 70, "Output"]
}, Open  ]],
Cell[24283, 824, 212, 4, 30, "Input"],

Cell[CellGroupData[{
Cell[24520, 832, 117, 2, 30, "Input"],
Cell[24640, 836, 232, 4, 70, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[24909, 845, 154, 3, 30, "Input"],
Cell[25066, 850, 155, 2, 70, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[25258, 857, 154, 3, 30, "Input"],
Cell[25415, 862, 74, 1, 70, "Output"]
}, Open  ]],
Cell[25504, 866, 134, 3, 30, "Input"],

Cell[CellGroupData[{
Cell[25663, 873, 79, 1, 30, "Input"],
Cell[25745, 876, 164, 3, 70, "Message"],
Cell[25912, 881, 168, 3, 70, "Output"]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{
Cell[26129, 890, 28, 0, 39, "Section"],
Cell[26160, 892, 210, 4, 30, "Input"],

Cell[CellGroupData[{
Cell[26395, 900, 50, 1, 30, "Input"],
Cell[26448, 903, 48, 1, 70, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[26533, 909, 183, 3, 30, "Input"],
Cell[26719, 914, 38, 1, 70, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[26794, 920, 436, 13, 30, "Input"],
Cell[27233, 935, 48, 1, 70, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[27318, 941, 80, 1, 30, "Input"],
Cell[27401, 944, 274, 4, 70, "Message"],
Cell[27678, 950, 241, 4, 70, "Message"],
Cell[27922, 956, 211, 3, 70, "Message"],
Cell[28136, 961, 241, 4, 70, "Message"],
Cell[28380, 967, 187, 3, 70, "Message"],
Cell[28570, 972, 164, 3, 70, "Message"],
Cell[28737, 977, 160, 3, 70, "Message"],
Cell[28900, 982, 227, 3, 70, "Message"],
Cell[29130, 987, 227, 3, 70, "Message"],
Cell[29360, 992, 215, 4, 70, "Message"],
Cell[29578, 998, 227, 3, 70, "Message"],
Cell[29808, 1003, 164, 3, 70, "Message"],
Cell[29975, 1008, 364, 6, 70, "Message"],
Cell[30342, 1016, 441, 7, 70, "Message"],
Cell[30786, 1025, 112, 2, 70, "Message"],
Cell[30901, 1029, 36, 1, 70, "Output"]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{
Cell[30986, 1036, 23, 0, 39, "Section"],
Cell[31012, 1038, 53, 1, 30, "Input"],

Cell[CellGroupData[{
Cell[31090, 1043, 70, 1, 30, "Input"],
Cell[31163, 1046, 46, 1, 70, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[31246, 1052, 139, 3, 30, "Input"],
Cell[31388, 1057, 102, 2, 70, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[31527, 1064, 144, 3, 30, "Input"],
Cell[31674, 1069, 87, 1, 70, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[31798, 1075, 89, 1, 30, "Input"],
Cell[31890, 1078, 38, 1, 70, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[31965, 1084, 86, 1, 30, "Input"],
Cell[32054, 1087, 35, 1, 70, "Output"]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{
Cell[32138, 1094, 29, 0, 39, "Section"],
Cell[32170, 1096, 72, 1, 30, "Input"],

Cell[CellGroupData[{
Cell[32267, 1101, 70, 1, 30, "Input"],
Cell[32340, 1104, 164, 3, 70, "Message"],
Cell[32507, 1109, 91, 1, 70, "Output"]
}, Open  ]],
Cell[32613, 1113, 76, 1, 30, "Input"],

Cell[CellGroupData[{
Cell[32714, 1118, 70, 1, 30, "Input"],
Cell[32787, 1121, 164, 3, 70, "Message"],
Cell[32954, 1126, 113, 2, 70, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[33104, 1133, 223, 4, 30, "Input"],
Cell[33330, 1139, 175, 4, 70, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[33542, 1148, 154, 3, 30, "Input"],
Cell[33699, 1153, 130, 2, 70, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[33866, 1160, 90, 1, 30, "Input"],
Cell[33959, 1163, 38, 1, 70, "Output"]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{
Cell[34046, 1170, 27, 0, 39, "Section"],

Cell[CellGroupData[{
Cell[34098, 1174, 90, 1, 30, "Input"],
Cell[34191, 1177, 85, 1, 70, "Output"]
}, Open  ]],
Cell[34291, 1181, 68, 1, 30, "Input"],
Cell[34362, 1184, 66, 1, 30, "Input"],

Cell[CellGroupData[{
Cell[34453, 1189, 44, 1, 30, "Input"],
Cell[34500, 1192, 35, 1, 70, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[34572, 1198, 115, 2, 30, "Input"],
Cell[34690, 1202, 301, 5, 70, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[35028, 1212, 59, 1, 30, "Input"],
Cell[35090, 1215, 71, 1, 70, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[35198, 1221, 59, 1, 30, "Input"],
Cell[35260, 1224, 114, 2, 70, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[35411, 1231, 88, 1, 30, "Input"],
Cell[35502, 1234, 114, 2, 70, "Output"]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{
Cell[35665, 1242, 40, 0, 39, "Section"],

Cell[CellGroupData[{
Cell[35730, 1246, 73, 1, 30, "Input"],
Cell[35806, 1249, 164, 3, 70, "Message"],
Cell[35973, 1254, 85, 1, 70, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[36095, 1260, 91, 1, 30, "Input"],
Cell[36189, 1263, 160, 3, 70, "Message"],
Cell[36352, 1268, 64, 1, 70, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[36453, 1274, 116, 2, 30, "Input"],
Cell[36572, 1278, 54, 1, 70, "Output"]
}, Open  ]]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{
Cell[36687, 1286, 28, 0, 53, "Subtitle"],

Cell[CellGroupData[{
Cell[36740, 1290, 126, 3, 59, "Section"],
Cell[36869, 1295, 65, 1, 30, "Input"],

Cell[CellGroupData[{
Cell[36959, 1300, 81, 1, 30, "Input"],
Cell[37043, 1303, 93, 1, 70, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[37173, 1309, 75, 1, 30, "Input"],
Cell[37251, 1312, 164, 3, 70, "Message"],
Cell[37418, 1317, 85, 1, 70, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[37540, 1323, 93, 1, 30, "Input"],
Cell[37636, 1326, 69, 1, 70, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[37742, 1332, 93, 1, 30, "Input"],
Cell[37838, 1335, 49, 1, 70, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[37924, 1341, 104, 2, 30, "Input"],
Cell[38031, 1345, 38, 1, 70, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[38106, 1351, 108, 2, 30, "Input"],
Cell[38217, 1355, 38, 1, 70, "Output"]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{
Cell[38304, 1362, 126, 3, 39, "Section"],
Cell[38433, 1367, 65, 1, 30, "Input"],

Cell[CellGroupData[{
Cell[38523, 1372, 199, 4, 30, "Input"],
Cell[38725, 1378, 166, 2, 70, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[38928, 1385, 75, 1, 30, "Input"],
Cell[39006, 1388, 232, 4, 70, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[39275, 1397, 93, 1, 30, "Input"],
Cell[39371, 1400, 151, 3, 70, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[39559, 1408, 93, 1, 30, "Input"],
Cell[39655, 1411, 74, 1, 70, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[39766, 1417, 211, 4, 30, "Input"],
Cell[39980, 1423, 38, 1, 70, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[40055, 1429, 124, 2, 30, "Input"],
Cell[40182, 1433, 38, 1, 70, "Output"]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{
Cell[40269, 1440, 122, 3, 39, "Section"],
Cell[40394, 1445, 54, 1, 30, "Input"],

Cell[CellGroupData[{
Cell[40473, 1450, 89, 1, 30, "Input"],
Cell[40565, 1453, 84, 1, 70, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[40686, 1459, 109, 2, 30, "Input"],
Cell[40798, 1463, 301, 5, 70, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[41136, 1473, 130, 2, 30, "Input"],
Cell[41269, 1477, 38, 1, 70, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[41344, 1483, 159, 3, 30, "Input"],
Cell[41506, 1488, 38, 1, 70, "Output"]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{
Cell[41593, 1495, 106, 3, 39, "Section"],
Cell[41702, 1500, 59, 1, 30, "Input"],

Cell[CellGroupData[{
Cell[41786, 1505, 85, 1, 30, "Input"],
Cell[41874, 1508, 93, 1, 70, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[42004, 1514, 75, 1, 30, "Input"],
Cell[42082, 1517, 164, 3, 70, "Message"],
Cell[42249, 1522, 66, 1, 70, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[42352, 1528, 93, 1, 30, "Input"],
Cell[42448, 1531, 69, 1, 70, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[42554, 1537, 121, 2, 30, "Input"],
Cell[42678, 1541, 38, 1, 70, "Output"]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{
Cell[42765, 1548, 110, 3, 39, "Section"],
Cell[42878, 1553, 65, 1, 30, "Input"],

Cell[CellGroupData[{
Cell[42968, 1558, 59, 1, 30, "Input"],
Cell[43030, 1561, 57, 1, 70, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[43124, 1567, 75, 1, 30, "Input"],
Cell[43202, 1570, 215, 4, 70, "Message"],
Cell[43420, 1576, 93, 1, 70, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[43550, 1582, 130, 2, 30, "Input"],
Cell[43683, 1586, 38, 1, 70, "Output"]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{
Cell[43770, 1593, 58, 2, 39, "Section"],
Cell[43831, 1597, 65, 1, 30, "Input"],

Cell[CellGroupData[{
Cell[43921, 1602, 68, 1, 30, "Input"],
Cell[43992, 1605, 72, 1, 70, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[44101, 1611, 75, 1, 30, "Input"],
Cell[44179, 1614, 175, 3, 70, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[44391, 1622, 93, 1, 30, "Input"],
Cell[44487, 1625, 77, 1, 70, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[44601, 1631, 93, 1, 30, "Input"],
Cell[44697, 1634, 96, 2, 70, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[44830, 1641, 126, 2, 30, "Input"],
Cell[44959, 1645, 38, 1, 70, "Output"]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{
Cell[45046, 1652, 58, 2, 39, "Section"],
Cell[45107, 1656, 65, 1, 30, "Input"],

Cell[CellGroupData[{
Cell[45197, 1661, 150, 3, 30, "Input"],
Cell[45350, 1666, 129, 2, 70, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[45516, 1673, 75, 1, 30, "Input"],
Cell[45594, 1676, 139, 2, 70, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[45770, 1683, 93, 1, 30, "Input"],
Cell[45866, 1686, 69, 1, 70, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[45972, 1692, 93, 1, 30, "Input"],
Cell[46068, 1695, 69, 1, 70, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[46174, 1701, 126, 2, 30, "Input"],
Cell[46303, 1705, 38, 1, 70, "Output"]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{
Cell[46390, 1712, 46, 0, 39, "Section"],
Cell[46439, 1714, 65, 1, 30, "Input"],

Cell[CellGroupData[{
Cell[46529, 1719, 59, 1, 30, "Input"],
Cell[46591, 1722, 58, 1, 70, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[46686, 1728, 75, 1, 30, "Input"],
Cell[46764, 1731, 164, 3, 70, "Message"],
Cell[46931, 1736, 164, 3, 70, "Message"],
Cell[47098, 1741, 56, 1, 70, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[47191, 1747, 93, 1, 30, "Input"],
Cell[47287, 1750, 51, 1, 70, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[47375, 1756, 107, 2, 30, "Input"],
Cell[47485, 1760, 38, 1, 70, "Output"]
}, Open  ]]
}, Closed]]
}, Closed]]
}
]
*)



(*******************************************************************
End of Mathematica Notebook file.
*******************************************************************)

